pub struct LocalDistributedQueue { /* private fields */ }Expand description
Local distributed queue implementation using multi-core parallelism
This is the default implementation that uses local channels for communication between partitions. Each partition runs on a separate tokio task, enabling efficient multi-core utilization.
Implementations
Sourceimpl LocalDistributedQueue
impl LocalDistributedQueue
Sourcepub fn new(partition_config: PartitionConfig) -> Self
pub fn new(partition_config: PartitionConfig) -> Self
Create a new local distributed queue with the specified partition configuration
Sourcepub fn partitioner(&self) -> &Arc<dyn Partitioner>
pub fn partitioner(&self) -> &Arc<dyn Partitioner>
Get the partitioner
Sourcepub fn partition_config(&self) -> &PartitionConfig
pub fn partition_config(&self) -> &PartitionConfig
Get the partition configuration
Sourcepub fn partition_receiver(
&self,
partition_id: PartitionId,
) -> Option<Arc<Mutex<Receiver<CommandEnvelope>>>>
pub fn partition_receiver( &self, partition_id: PartitionId, ) -> Option<Arc<Mutex<Receiver<CommandEnvelope>>>>
Get the receiver for a specific partition (for worker tasks)
Sourcepub fn result_receiver(&self) -> Arc<Mutex<Receiver<CommandResult>>>
pub fn result_receiver(&self) -> Arc<Mutex<Receiver<CommandResult>>>
Get the result receiver (for coordinator to collect results)
Sourcepub fn result_sender(&self) -> Sender<CommandResult>
pub fn result_sender(&self) -> Sender<CommandResult>
Get the result sender (for workers to send results)