pub struct PriorityItem<T> { /* private fields */ }Expand description
One queued value together with its stable scheduling metadata.
Implementations
Sourceimpl<T> PriorityItem<T>
impl<T> PriorityItem<T>
Sourcepub fn sequence(&self) -> u64
pub fn sequence(&self) -> u64
Monotonic insertion order used for FIFO scheduling within a priority.
Sourcepub fn into_value(self) -> T
pub fn into_value(self) -> T
Consume the scheduling metadata and return the queued value.